@@ -2,7 +2,7 @@
 #' Generate Data for Beta MPT Models
 #'
 #' Generating a data file with known parameter structure using the Beta-MPT. Useful for simulations and robustness checks.
-#'
+#' @inheritParams betaMPT
 #' @inheritParams genMPT
 #' @param N number of participants
 #' @param mean Named vector of true group means of individual MPT parameters. If the vector is not named, the internal order of parameters is used (can be obtained using \code{\link{readEQN}}).
@@ -24,20 +24,31 @@
 #'                      mean = c(Do=.7, Dn=.5, g=.5),
 #'                      sd =   c(Do=.1, Dn=.1, g=.05))
 #' head(genDat$data, 3)
+#' plotFreq(genDat$data, eqn=EQNfile)
 #' @importFrom stats  rbeta
 #' @references Smith, J. B., & Batchelder, W. H. (2010). Beta-MPT: Multinomial processing tree models for addressing individual differences. Journal of Mathematical Psychology, 54, 167-183.
 #' @export
-genBetaMPT <- function(N, numItems, eqnfile, mean=NULL, sd=NULL, alpha=NULL, beta=NULL){
-
+genBetaMPT <- function(N, numItems, eqnfile, restrictions,
+                       mean=NULL, sd=NULL,
+                       alpha=NULL, beta=NULL,
+                       warning=TRUE){
+  if(missing(restrictions))
+    restrictions <- NULL
   Tree <- readEQN(eqnfile)
   mergedTree <- mergeBranches(Tree)
-  thetaNames <- getParameter(mergedTree)
+  Tree.restr <- thetaHandling(mergedTree,restrictions)
+  thetaNames <-  Tree.restr$SubPar[,1:2]
+  thetaNames <- thetaNames[rownames(unique(thetaNames[2])),]$Parameter
+  treeLabels <- unique(mergedTree$Tree)
+
+  # mergedTree <- mergeBranches(Tree)
+  # thetaNames <- getParameter(mergedTree)
   S <- length(thetaNames)
 
 
-  if(!is.null(mean) & !is.null(sd)){
-    mean <- checkNaming(S, thetaNames, mean, "mean")
-    sd <- checkNaming(S, thetaNames, sd, "sd")
+  if(!is.null(mean) && !is.null(sd)){
+    mean <- checkNaming(S, thetaNames, mean, "mean", warning=warning)
+    sd <- checkNaming(S, thetaNames, sd, "sd", warning=warning)
 
     alpha <- ((1 - mean) / sd^2 - 1 / mean) * mean ^ 2
     beta <- alpha * (1 / mean - 1)
@@ -45,10 +56,11 @@ genBetaMPT <- function(N, numItems, eqnfile, mean=NULL, sd=NULL, alpha=NULL, bet
     #     alpha <- -(mean*(mean^2-mean+sd^2))/sd^2
     #     beta <- ((mean-1)*(mean^2-mean+sd^2))/sd^2
     if(any(alpha<=0) | any(beta<=0))
-      stop("Check numerical values for mean and sd, result in negative alpha/beta parameters of beta-hyperprior distribution.")
-  }else if(!is.null(alpha) & !is.null(beta)){
-    alpha <- checkNaming(S, thetaNames, alpha, "alpha")
-    beta <- checkNaming(S, thetaNames, beta, "beta")
+      stop("Check numerical values for mean and sd, result in negative alpha/beta\n",
+           "parameters of beta-hyperprior distribution.")
+  }else if(!is.null(alpha) && !is.null(beta)){
+    alpha <- checkNaming(S, thetaNames, alpha, "alpha", warning=warning)
+    beta <- checkNaming(S, thetaNames, beta, "beta", warning=warning)
 
   }else{
     stop("Either 'mean' and 'sd' or 'alpha' and 'beta' must be provided.")
@@ -57,7 +69,7 @@ genBetaMPT <- function(N, numItems, eqnfile, mean=NULL, sd=NULL, alpha=NULL, bet
   # individual parameters, drawn from hierarchical distribution:
   theta <- c()
   for(s in 1:S){
-    if(sd[s] == 0){
+    if(!is.null(sd) && sd[s] == 0){
       theta <- cbind(theta,rep(mean[s],N))
     }else{
       theta <- cbind(theta, rbeta(N, shape1 = alpha[s], shape2 = beta[s]))
@@ -66,7 +78,7 @@ genBetaMPT <- function(N, numItems, eqnfile, mean=NULL, sd=NULL, alpha=NULL, bet
   colnames(theta) <- thetaNames
 
   # response frequencies:
-  freq <- genMPT(theta, numItems, eqnfile)
+  freq <- genMPT(theta, numItems, eqnfile, restrictions, warning=warning)
 
   res <- list(data = freq, parameters = list(theta=theta, mean=mean,
                                              sd=sd, alpha=alpha, beta=beta))
